==> release.12.0.73.1.tgz: cgi-cpn/prontus_preview_garbage_collector.pl <==
#!/usr/bin/perl

# ---------------------------------------------------------------
# Prontus CMS
# http://www.prontus.cl
# by Altavoz.net
#
# licensed under LGPL license.
# http://www.prontus.cl/license.html
# ---------------------------------------------------------------
use strict;
use utf8;

BEGIN {
    use FindBin qw($Bin);
    unshift(@INC,$Bin);
}

use lib_prontus;
use prontus_varglb;
&prontus_varglb::init();
use lib_stdlog;
&lib_stdlog::set_stdlog($0, 51200);

my $PRONTUS_ID;
my $MAXTIME = 1800;

main: {
    &lib_prontus::setUtf8();
    if (&myself_running() > 1) {
        print STDERR "Hay otro proceso corriendo: $0\n";
        print "Hay otro proceso corriendo: $0\n";
        exit;
    };

    if ($ARGV[0] ne '') {
        $PRONTUS_ID = $ARGV[0];
    } else {
        print STDERR "prontus_id no especificado.\n";
        print "prontus_id no especificado.\n";
        exit;
    }

    my $msg_load = &lib_prontus::load_config_by_id($PRONTUS_ID);

    if ($msg_load ne '') {
        print STDERR "No se pudo cargar la configuracion de prontus [$msg_load]\n";
        print "No se pudo cargar la configuracion de prontus [$msg_load]\n";
        exit;
    }

    my $level = 0;
    &do_garbage_collector("$prontus_varglb::DIR_SERVER$prontus_varglb::CONFIG{$prontus_varglb::PRONTUS_ID}{'DIR_SITE'}/preview", $level);

};

sub do_garbage_collector {
    my $path = $_[0];
    my $level = $_[1];
    if ($level > 3) {
        print STDERR "Recursividad máxima excedida\n";
        print "Recursividad máxima excedida\n";
    }
    $level++;

    my @files = glob "$path/*";
    my $mtime;
    my $time = time;
    my $file_age;

    foreach my $file (@files) {
        $file =~ s/\n//sg;
        # print "file[$file]\n";
        $mtime = (stat($file))[9];
        $file_age = $time - $mtime;

        # Eliminar archivo si es mas antiguo que MAXTIME.
        if (-f $file && $file_age > $MAXTIME) {
            unlink $file;
        }

        # Eliminar directorio si esta vacio.
        if (-d $file) {
            # intenta borrar el contenido del directorio
            &do_garbage_collector($file, $level);
            # si quedo vacío lo borra
            if (if_dir_is_empty($file)) {
                # print "esta vacio\n";
                rmdir $file;
            }
        }
    }
};

# Verifica si el diretorio dado esta vacio.
sub if_dir_is_empty {
    my $path = $_[0];
    my @files = glob("$path/*");
    my $empty = 1;

    # print "dir[$path]\n";
    foreach my $file (@files) {
        next if ($file eq '.' or $file eq '..');
        $empty = 0;
        last;
    }

    return $empty;
}

# Detecta cuantas copias de este script estan corriendo.
sub myself_running {
    my(@result) = qx/ps axww | grep $0 | grep -v ' grep ' | grep -v 'nice' | grep -v 'editor' | grep -v 'sh -c' | grep -v execIfMaster | grep -v 'tail'/; # wc -l
    my $res = 0;
    foreach my $line (@result) {
        #print "line = [$line] [$0]\n";
        if ($line =~ /$0/) {
            $res++;
        }
    }
    return $res;
} # myself_running

==> release.12.2.28.1.tgz: cgi-cpn/prontus_preview_garbage_collector.pl <==
#!/usr/bin/perl

# ---------------------------------------------------------------
# Prontus CMS
# http://www.prontus.cl
# by Altavoz.net
#
# licensed under LGPL license.
# http://www.prontus.cl/license.html
# ---------------------------------------------------------------
use strict;
use utf8;

BEGIN {
    use FindBin qw($Bin);
    unshift(@INC,$Bin);
}

##libs##
use lib_stdlog;
lib_stdlog::set_stdlog($0, 51200);
use prontus_varglb;
prontus_varglb::init();

use File::Copy;
use glib_fildir_03;
use lib_utils;
##/libs##

my $PRONTUS_ID;
my $MAXTIME = 1800;

main: {
    lib_utils::setUtf8();
    if (&myself_running() > 1) {
        print STDERR "Hay otro proceso corriendo: $0\n";
        print "Hay otro proceso corriendo: $0\n";
        exit;
    };

    if ($ARGV[0] ne '') {
        $PRONTUS_ID = $ARGV[0];
    } else {
        print STDERR "prontus_id no especificado.\n";
        print "prontus_id no especificado.\n";
        exit;
    }

    my $msg_load = lib_utils::load_config_by_id($PRONTUS_ID);

    if ($msg_load ne '') {
        print STDERR "No se pudo cargar la configuracion de prontus [$msg_load]\n";
        print "No se pudo cargar la configuracion de prontus [$msg_load]\n";
        exit;
    }

    my $level = 0;
    &do_garbage_collector("$prontus_varglb::DIR_SERVER$prontus_varglb::CONFIG{$prontus_varglb::PRONTUS_ID}{'DIR_SITE'}/preview", $level);
}

sub do_garbage_collector {
    my $path = $_[0];
    my $level = $_[1];
    if ($level > 3) {
        print STDERR "Recursividad máxima excedida\n";
        print "Recursividad máxima excedida\n";
    }
    $level++;

    my @files = glob "$path/*";
    my $mtime;
    my $time = time;
    my $file_age;

    foreach my $file (@files) {
        $file =~ s/\n//sg;
        # print "file[$file]\n";
        $mtime = (stat($file))[9];
        $file_age = $time - $mtime;

        # Eliminar archivo si es mas antiguo que MAXTIME.
        if (-f $file && $file_age > $MAXTIME) {
            unlink $file;
        }

        # Eliminar directorio si esta vacio.
        if (-d $file) {
            # intenta borrar el contenido del directorio
            &do_garbage_collector($file, $level);
            # si quedo vacío lo borra
            if (if_dir_is_empty($file)) {
                # print "esta vacio\n";
                rmdir $file;
            }
        }
    }
}

# Verifica si el diretorio dado esta vacio.
sub if_dir_is_empty {
    my $path = $_[0];
    my @files = glob("$path/*");
    my $empty = 1;

    # print "dir[$path]\n";
    foreach my $file (@files) {
        next if ($file eq '.' or $file eq '..');
        $empty = 0;
        last;
    }

    return $empty;
}

# Detecta cuantas copias de este script estan corriendo.
sub myself_running {
    my(@result) = qx/ps axww | grep $0 | grep -v ' grep ' | grep -v 'nice' | grep -v 'editor' | grep -v 'sh -c' | grep -v execIfMaster | grep -v 'tail'/; # wc -l
    my $res = 0;
    foreach my $line (@result) {
        #print "line = [$line] [$0]\n";
        if ($line =~ /$0/) {
            $res++;
        }
    }
    return $res;
} # myself_running
